@@ -93,9 +93,7 @@ sub _handler {
             # We use instance here because if we store $request we get a
             # circular reference and a big memory leak.
             if (!$sent_headers and HTML::Mason::Request->instance->auto_send_headers) {
-                unless ($r->http_header_sent) {
-                    $r->send_http_header();
-                }
+                $r->send_http_header();
                 $sent_headers = 1;
             }
 
@@ -225,12 +223,18 @@ sub redirect {
 }
 
 1;
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::CGIHandler - Use Mason in a CGI environment
 
+=head1 VERSION
+
+version 1.50
+
 =head1 SYNOPSIS
 
 In httpd.conf or .htaccess:
@@ -601,8 +605,35 @@ of its values will be in the table any longer.
 
 =head1 SEE ALSO
 
-L<HTML::Mason|HTML::Mason>,
-L<HTML::Mason::Admin|HTML::Mason::Admin>,
-L<HTML::Mason::ApacheHandler|HTML::Mason::ApacheHandler>
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
