@@ -3,6 +3,9 @@
 # under the same terms as Perl itself.
 
 package HTML::Mason::Cache::BaseCache;
+BEGIN {
+  $HTML::Mason::Cache::BaseCache::VERSION = '1.50';
+}
 use strict;
 use warnings;
 
@@ -76,12 +79,18 @@ sub expire_if
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Cache::BaseCache - Base cache object
 
+=head1 VERSION
+
+version 1.50
+
 =head1 DESCRIPTION
 
 This is the base module for all cache implementations used in Mason.
@@ -168,4 +177,37 @@ days, w, week, weeks, M, month, months, y, year, and years.
 
 =back
 
+=head1 SEE ALSO
+
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
