@@ -3,6 +3,9 @@
 # under the same terms as Perl itself.
 
 package HTML::Mason::Compiler;
+BEGIN {
+  $HTML::Mason::Compiler::VERSION = '1.50';
+}
 
 use strict;
 use warnings;
@@ -707,12 +710,18 @@ sub HTML::Mason::Parser::new
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Compiler - Compile Mason component source
 
+=head1 VERSION
+
+version 1.50
+
 =head1 SYNOPSIS
 
   package My::Funky::Compiler;
@@ -982,12 +991,37 @@ We recommend that any parameters you add to Compiler be read-only,
 because the compiler object_id is only computed once on creation
 and would not reflect any changes to Lexer parameters.
 
-=cut
-
 =head1 SEE ALSO
 
-L<HTML::Mason|HTML::Mason>,
-L<HTML::Mason::Admin|HTML::Mason::Admin>,
-L<HTML::Mason::Interp|HTML::Mason::Interp>
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
