@@ -3,6 +3,9 @@
 # under the same terms as Perl itself.
 
 package HTML::Mason::Component;
+BEGIN {
+  $HTML::Mason::Component::VERSION = '1.50';
+}
 
 use strict;
 use warnings;
@@ -387,12 +390,18 @@ sub logger {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Component - Mason Component Class
 
+=head1 VERSION
+
+version 1.50
+
 =head1 SYNOPSIS
 
     my $comp1 = $m->current_comp;
@@ -637,8 +646,35 @@ Returns the directory of the source filename for this component.
 
 =head1 SEE ALSO
 
-L<HTML::Mason|HTML::Mason>,
-L<HTML::Mason::Devel|HTML::Mason::Devel>,
-L<HTML::Mason::Request|HTML::Mason::Request>
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
