@@ -3,6 +3,9 @@
 # it under the same terms as Perl itself.
 
 package HTML::Mason::Component::FileBased;
+BEGIN {
+  $HTML::Mason::Component::FileBased::VERSION = '1.50';
+}
 
 use strict;
 use warnings;
@@ -50,12 +53,18 @@ sub assign_runtime_properties {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Component::FileBased - Mason File-Based Component Class
 
+=head1 VERSION
+
+version 1.50
+
 =head1 DESCRIPTION
 
 This is a subclass of
@@ -70,6 +79,35 @@ documentation.
 
 =head1 SEE ALSO
 
-L<HTML::Mason::Component|HTML::Mason::Component>
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
