@@ -3,6 +3,9 @@
 # it under the same terms as Perl itself.
 
 package HTML::Mason::Component::Subcomponent;
+BEGIN {
+  $HTML::Mason::Component::Subcomponent::VERSION = '1.50';
+}
 
 use strict;
 use warnings;
@@ -31,7 +34,9 @@ sub assign_runtime_properties {
     $self->SUPER::assign_runtime_properties($interp, $source);
     $self->{comp_id} = sprintf("[%s '%s' of %s]", $self->{is_method} ? 'method' : 'subcomponent',
                                $self->name, $self->owner->comp_id);
-    $self->{path} = $self->owner->path . ":" . $self->name;
+    my $owner_path = $self->owner->path;
+    $owner_path = q{} unless defined $owner_path;
+    $self->{path} =  $owner_path . ":" . $self->name;
 }
 
 sub cache_file { return $_[0]->owner->cache_file }
@@ -46,12 +51,18 @@ sub title { return $_[0]->owner->title . ":" . $_[0]->name }
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Component::Subcomponent - Mason Subcomponent Class
 
+=head1 VERSION
+
+version 1.50
+
 =head1 DESCRIPTION
 
 This is a subclass of
@@ -83,6 +94,35 @@ was defined.
 
 =head1 SEE ALSO
 
-L<HTML::Mason::Component|HTML::Mason::Component>
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
