@@ -3,6 +3,9 @@
 # under the same terms as Perl itself.
 
 package HTML::Mason::ComponentSource;
+BEGIN {
+  $HTML::Mason::ComponentSource::VERSION = '1.50';
+}
 
 use strict;
 use warnings;
@@ -82,12 +85,18 @@ sub object_code
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::ComponentSource - represents information about an component
 
+=head1 VERSION
+
+version 1.50
+
 =head1 SYNOPSIS
 
     my $info = $resolver->get_info($comp_path);
@@ -201,4 +210,37 @@ L<HTML::Mason|HTML::Mason>,
 L<HTML::Mason::Admin|HTML::Mason::Admin>,
 L<HTML::Mason::Component|HTML::Mason::Component>
 
+=head1 SEE ALSO
+
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
