@@ -7,11 +7,15 @@
 #
 
 package HTML::Mason::Escapes;
+BEGIN {
+  $HTML::Mason::Escapes::VERSION = '1.50';
+}
 
 use strict;
 use warnings;
 
-use HTML::Mason::Tools qw(load_pkg);
+use HTML::Entities ();
+
 
 my %html_escape = ('&' => '&amp;', '>'=>'&gt;', '<'=>'&lt;', '"'=>'&quot;');
 my $html_escape = qr/([&<>"])/;
@@ -27,9 +31,6 @@ sub html_entities_escape
 {
     return unless defined ${ $_[0] };
 
-    load_pkg( 'HTML::Entities',
-              'HTML escaping requires the HTML::Entities module, available from CPAN.');
-
     HTML::Entities::encode_entities( ${ $_[0] } );
 }
 
@@ -37,18 +38,25 @@ sub url_escape
 {
     return unless defined ${ $_[0] };
 
+    use bytes;
     ${ $_[0] } =~ s/([^a-zA-Z0-9_.-])/uc sprintf("%%%02x",ord($1))/eg;
 }
 
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Escapes - Functions to escape text for Mason
 
+=head1 VERSION
+
+version 1.50
+
 =head1 DESCRIPTION
 
 This module contains functions for implementing Mason's L<substitution
@@ -97,4 +105,37 @@ details.
 
 =back
 
+=head1 SEE ALSO
+
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
