@@ -441,12 +441,18 @@ sub full_message
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Exceptions - Exception objects thrown by Mason
 
+=head1 VERSION
+
+version 1.50
+
 =head1 SYNOPSIS
 
   use HTML::Mason::Exceptions ( abbr => [ qw(system_error) ] );
@@ -617,4 +623,37 @@ or
 Note that when specifying a subclass you should not include the
 leading "HTML::Mason::Exception::" portion of the class name.
 
+=head1 SEE ALSO
+
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
