@@ -9,8 +9,12 @@
 # 
 
 package HTML::Mason::Handler;
+BEGIN {
+  $HTML::Mason::Handler::VERSION = '1.50';
+}
 
 use strict;
+use warnings;
 
 use HTML::Mason::Exceptions ( abbr => [ qw( virtual_error ) ] );
 
