@@ -5,6 +5,9 @@
 # under the same terms as Perl itself.
 
 package HTML::Mason::Interp;
+BEGIN {
+  $HTML::Mason::Interp::VERSION = '1.50';
+}
 
 use strict;
 use warnings;
@@ -1022,12 +1025,18 @@ sub apply_escapes
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Interp - Mason Component Interpreter
 
+=head1 VERSION
+
+version 1.50
+
 =head1 SYNOPSIS
 
     my $i = HTML::Mason::Interp->new (data_dir=>'/usr/local/mason',
@@ -1440,8 +1449,35 @@ C<strict>.
 
 =head1 SEE ALSO
 
-L<HTML::Mason|HTML::Mason>,
-L<HTML::Mason::Admin|HTML::Mason::Admin>,
-L<HTML::Mason::ApacheHandler|HTML::Mason::ApacheHandler>
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
