@@ -3,6 +3,9 @@
 # under the same terms as Perl itself.
 
 package HTML::Mason::MethodMaker;
+BEGIN {
+  $HTML::Mason::MethodMaker::VERSION = '1.50';
+}
 
 use strict;
 use warnings;
@@ -108,12 +111,18 @@ sub import
 
 1;
 
+
+__END__
 =pod
 
 =head1 NAME
 
 HTML::Mason::MethodMaker - Used to create simple get & get/set methods in other classes
 
+=head1 VERSION
+
+version 1.50
+
 =head1 SYNOPSIS
 
  use HTML::Mason::MethodMaker
@@ -171,6 +180,32 @@ as the parameters given for 'read_write' accessors.
 
 =head1 SEE ALSO
 
-L<HTML::Mason|HTML::Mason>
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
