@@ -1,4 +1,7 @@
 package HTML::Mason::Plugin;
+BEGIN {
+  $HTML::Mason::Plugin::VERSION = '1.50';
+}
 
 use strict;
 use warnings;
@@ -30,12 +33,34 @@ sub end_component_hook {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Plugin - Plugin Base class for Mason
 
+=head1 VERSION
+
+version 1.50
+
+=head1 DESCRIPTION
+
+Use a Mason plugin to have actions occur at the beginning or end of
+requests or components. Plugins are activated by passing L<plugins|HTML::Mason::Params/plugins> in
+the interpreter or request object. Each plugin in the list can be
+specified as a class name (in which case the plugin object is created
+once for each request) or as an actual object of the plugin class.
+
+If your plugin can be configured, place the configuration in class
+variables - for example,
+
+    $MasonX::Plugin::Timer::Units = 'seconds';
+
+These can be set either from httpd.conf via PerlSetVar
+directives, or in perl directly from a handler.pl file.
+
 =head1 SYNOPIS
 
    package MasonX::Plugin::Timer;
@@ -56,22 +81,6 @@ HTML::Mason::Plugin - Plugin Base class for Mason
 
    1;
 
-=head1 DESCRIPTION
-
-Use a Mason plugin to have actions occur at the beginning or end of
-requests or components. Plugins are activated by passing L<plugins|HTML::Mason::Params/plugins> in
-the interpreter or request object. Each plugin in the list can be
-specified as a class name (in which case the plugin object is created
-once for each request) or as an actual object of the plugin class.
-
-If your plugin can be configured, place the configuration in class
-variables - for example,
-
-    $MasonX::Plugin::Timer::Units = 'seconds';
-
-These can be set either from httpd.conf via PerlSetVar
-directives, or in perl directly from a handler.pl file.
-
 =head1 PLUGIN HOOKS
 
 A plugin class defines one or more of the following hooks (methods):
@@ -172,12 +181,37 @@ because output from multiple components combine into a single buffer.
 Do not keep an unweakened reference to a request or component object
 in your plugin object, or you will create a nasty circular reference.
 
-=head1 AUTHORS
-
-Doug Treder, Jonathan Swartz, Dave Rolsky
-
 =head1 SEE ALSO
 
-L<HTML::Mason::Interp|HTML::Mason::Interp>, L<HTML::Mason::Request|HTML::Mason::Request>
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
