@@ -3,6 +3,9 @@
 # it under the same terms as Perl itself.
 
 package HTML::Mason::Resolver::Null;
+BEGIN {
+  $HTML::Mason::Resolver::Null::VERSION = '1.50';
+}
 
 use strict;
 use warnings;
@@ -28,12 +31,18 @@ sub glob_path {
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Resolver::Null - a do-nothing resolver
 
+=head1 VERSION
+
+version 1.50
+
 =head1 SYNOPSIS
 
   my $resolver = HTML::Mason::Resolver::Null->new;
@@ -69,6 +78,35 @@ EOF
 
 =head1 SEE ALSO
 
-L<HTML::Mason|HTML::Mason>
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
