@@ -1,4 +1,7 @@
 package HTML::Mason::Tests;
+BEGIN {
+  $HTML::Mason::Tests::VERSION = '1.50';
+}
 
 use strict;
 use warnings;
@@ -296,12 +299,12 @@ sub base_path
 
     if (ref $proto)
     {
-        $proto->{base_path} ||= File::Spec->catdir( cwd(), 'mason_tests' );
+        $proto->{base_path} ||= File::Spec->catdir( cwd(), 'mason_tests', $$ );
         return $proto->{base_path};
     }
     else
     {
-        return File::Spec->catdir( cwd(), 'mason_tests' );
+        return File::Spec->catdir( cwd(), 'mason_tests', $$ );
     }
 }
 
@@ -676,12 +679,18 @@ sub _cleanup
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Tests - Test harness for testing Mason
 
+=head1 VERSION
+
+version 1.50
+
 =head1 SYNOPSIS
 
  use HTML::Mason::Tests;
@@ -962,6 +971,35 @@ that overrides the _make_interp method to use your subclass:
 
 =head1 SEE ALSO
 
-L<HTML::Mason|HTML::Mason>
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
