@@ -8,6 +8,9 @@
 #
 
 package HTML::Mason::Utils;
+BEGIN {
+  $HTML::Mason::Utils::VERSION = '1.50';
+}
 
 use HTML::Mason::Tools qw(compress_path);
 use strict;
@@ -52,12 +55,18 @@ sub cgi_request_args
 
 1;
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 HTML::Mason::Utils - Publicly available functions useful outside of Mason
 
+=head1 VERSION
+
+version 1.50
+
 =head1 DESCRIPTION
 
 The functions in this module are useful when you need to interface
@@ -89,5 +98,38 @@ references.
 
 =back
 
+=head1 SEE ALSO
+
+L<Mason|Mason>
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Ken Williams <ken@mathforum.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Jonathan Swartz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
+
